@@ -9,7 +9,7 @@ from .Server import *
 
 class FlaskContextCreator(IQRContextCreator):
     def create_context(self, request, rep: IQRRepository) -> QRContext:
-        json = request.get_json()
+        json = request.get_json(silent=True)
         if json is None:
             json = dict()
         return QRContext(json, request.args, request.headers, request.form, request.files, rep)
