@@ -1,8 +1,8 @@
 import datetime
 import jwt
-from IQRServer import *
 from abc import abstractmethod
 
+from .Server import *
 
 class ITokenManager(IQRManager):
     @staticmethod
